#ifndef __FLASH_HANDLER_H__
#define __FLASH_HANDLER_H__

#include "user_config.h"
#include "ble_atHandler.h"

typedef struct _uartConfig_t
{ 
	uint32_t br;
	uint16_t stop_bit;
	uint16_t parity;
	uint16_t flow_control;
	uint16_t flow_control_threshold;
} uartConfig_t;


typedef struct	_conInterval_t
{ 
	uint16_t conInterval;
	uint16_t latency;
} conInterval_t;


typedef  struct 
{	
		
	uartConfig_t 		uart_cfg;																				/* uart config information*/		
	uint16_t				adver_interval;																	/* advering interval time*/
	conInterval_t 	con_interval ;																	/* connect interval time*/	
	int16_t 				tx_power;																			  /* tx power */	

	uint8_t         delay_time[3];	
	uint8_t		 			device_name[BLE_DEVICE_NAME_MAX_LENGTH+4];				/* device name */	
	
	uint16_t 				adv_enable;																			/* advering switch flag*/		
	uint16_t        bond_mode;
	uint8_t 				passkey[8];																				/* pass key*/	
	uint8_t 				btAddr[MAC_LENGTH];  														/* mac addr */	
	uint8_t					DeviceType[24];
	uint8_t					manufac_name[22];
	uint8_t					serial_num[22];	
	uint8_t					hardware_rev[22];
	uint8_t					software_rev[22];
	uint8_t					IEE_11073[22];
	uint8_t 				encry_type[4];
	uint8_t					pnp_data[22];		
}at_com_data_t;

extern uint8_t   fs_event_num;	
extern at_com_data_t	at_com_data;

extern void getUartConfig(void);
extern void getConnInterval(void);
extern uint8_t* getDeviceName(void);
extern uint16_t getAdvInterval(void);
extern uint8_t getTxPower(void);
extern uint8_t getUartDelayTime(void);
extern void Appcfg_RecoveryHandler(void);

extern void saveUartConfig(uartConfig_t* pConfig);
extern void saveConnInterval(conInterval_t *conInterval);
extern void saveDeviceName(uint8_t * name_arry);
extern void saveAdvInterval(uint16_t AdvInterval);
extern void saveTxPower(uint8_t TxPower);
extern void saveUartDelayTime(uint8_t DelayTime);

extern void flash_init(void);
extern void wait_flash_complete(void);
extern void flash_clear(void);
extern void read_clear_data(void);
extern void flash_read(uint8_t *dat,uint16_t len);
extern void flash_write(uint8_t *dat,uint16_t len);
extern void PowerUp_write_timer_init(void);


#endif 

